==> gtk+-2.13.0.tar.bz2: gtk+-2.13.0/modules/other/gail/gaillabel.h <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GAIL_LABEL_H__
#define __GAIL_LABEL_H__

#include <gtk/gtkaccessible.h>
#include <gail/gailwidget.h>
#include <libgail-util/gailtextutil.h>

G_BEGIN_DECLS

#define GAIL_TYPE_LABEL                      (gail_label_get_type ())
#define GAIL_LABEL(obj)                      (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAIL_TYPE_LABEL, GailLabel))
#define GAIL_LABEL_CLASS(klass)              (G_TYPE_CHECK_CLASS_CAST ((klass), GAIL_TYPE_LABEL, GailLabelClass))
#define GAIL_IS_LABEL(obj)                   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAIL_TYPE_LABEL))
#define GAIL_IS_LABEL_CLASS(klass)           (G_TYPE_CHECK_CLASS_TYPE ((klass), GAIL_TYPE_LABEL))
#define GAIL_LABEL_GET_CLASS(obj)            (G_TYPE_INSTANCE_GET_CLASS ((obj), GAIL_TYPE_LABEL, GailLabelClass))

typedef struct _GailLabel              GailLabel;
typedef struct _GailLabelClass         GailLabelClass;

struct _GailLabel
{
  GailWidget parent;

  GailTextUtil   *textutil;
  gint           cursor_position;
  gint           selection_bound;
  gint           label_length;
  guint          window_create_handler;
  gboolean       has_top_level;
};

GType gail_label_get_type (void);

struct _GailLabelClass
{
  GailWidgetClass parent_class;
};

G_END_DECLS

#endif /* __GAIL_LABEL_H__ */

==> gtk+-2.99.3.tar.bz2: gtk+-2.99.3/modules/other/gail/gaillabel.h <==
/* GAIL - The GNOME Accessibility Implementation Library
 * Copyright 2001 Sun Microsystems Inc.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

#ifndef __GAIL_LABEL_H__
#define __GAIL_LABEL_H__

#include <gail/gailwidget.h>
#include <libgail-util/gailtextutil.h>

G_BEGIN_DECLS

#define GAIL_TYPE_LABEL                      (gail_label_get_type ())
#define GAIL_LABEL(obj)                      (G_TYPE_CHECK_INSTANCE_CAST ((obj), GAIL_TYPE_LABEL, GailLabel))
#define GAIL_LABEL_CLASS(klass)              (G_TYPE_CHECK_CLASS_CAST ((klass), GAIL_TYPE_LABEL, GailLabelClass))
#define GAIL_IS_LABEL(obj)                   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GAIL_TYPE_LABEL))
#define GAIL_IS_LABEL_CLASS(klass)           (G_TYPE_CHECK_CLASS_TYPE ((klass), GAIL_TYPE_LABEL))
#define GAIL_LABEL_GET_CLASS(obj)            (G_TYPE_INSTANCE_GET_CLASS ((obj), GAIL_TYPE_LABEL, GailLabelClass))

typedef struct _GailLabel              GailLabel;
typedef struct _GailLabelClass         GailLabelClass;

struct _GailLabel
{
  GailWidget parent;

  GailTextUtil   *textutil;
  gint           cursor_position;
  gint           selection_bound;
  gint           label_length;
  gulong         window_create_handler;
  gboolean       has_top_level;
};

GType gail_label_get_type (void);

struct _GailLabelClass
{
  GailWidgetClass parent_class;
};

G_END_DECLS

#endif /* __GAIL_LABEL_H__ */
